/*
 * dbconnect.java
 *
 * Copyright(c) 2000-2001, Particle
 */

/*
 * NOTE: Before you run this program you need to create a valid DSN,
 *  read the source on direction how to do it.
 *
 * NOTE 2: there is a sample db session at the end of this file using
 * this program.
 */

import java.lang.*;
import java.util.*;
import java.sql.*;
import java.io.*;

/**
 * dbconnect is a class to play around with db
 *
 * It acts like an EXTREMELY simple 'Access' program.
 * (ie: MS Access is just a GUI calling these drivers, so, is this program!)
 */
public class dbconnect {

    /**
     * main method that drives the whole thing
     */
    public static void main(String[] args) throws Throwable {

        // load db driver
        Class.forName("sun.jdbc.odbc.JdbcOdbcDriver").newInstance();

        // get list of loaded database drivers
        Enumeration enum = DriverManager.getDrivers();

        // print out some info about the drivers
        while (enum.hasMoreElements()) {
            Driver driver = (Driver)enum.nextElement();
            System.out.println("Driver: "+driver.getClass().getName());
            System.out.println("Major Version: "+driver.getMajorVersion());
            System.out.println("Minor Version: "+driver.getMinorVersion());
        }

        // print out some status
        System.out.println("\nConnecting to jdbc:odbc:Test ...\n");

        // connect with a Data Source Name (DSN) of a database.
        Connection connection = DriverManager.getConnection("jdbc:odbc:Test");

        // the jdbc:odbc:Test is a connection URL. The name "Test" is the DSN
        // for a sample ODBC database.

        // to setup an ODBC database, under Windows 95/98/NT go into control
        // panel, and click "ODBC Data Sources". Under Windows 2000, go to
        // control panel, then into "Administrative Tools", then click on
        // "Data Sources (ODBC)".
        // If it is your home machine, you'd want to go into the "System DSN"
        // tab. Click "Add..." Pick a simple driver. There are many different
        // ones. Simplest one is "Microsoft Access Driver (*.mdb)"
        // This is the driver that Microsoft Access uses to access their
        // databases. Yes, Access is just a GUI tool that calls this driver.

        // click "Finish" to add that DSN. A driver setup dialog box should
        // appear. Type in the desired Data Source Name, in our case, "Test".
        // If it is an Access driver, you can create a new database, or choose
        // a mdb file. For this sample, create test.mdb in some appropriate
        // directory. Click Ok to finish.

        // You are done! You can now execute commands on this database.

        // First, lets get some database information.

        DatabaseMetaData databaseMetaData = connection.getMetaData();
        System.out.println("Database: "+databaseMetaData.getDatabaseProductName());
        System.out.println("Version: "+databaseMetaData.getDatabaseProductVersion());
        System.out.println("User: "+databaseMetaData.getUserName());

        System.out.println("type 'help' for help. type 'quit' to exit.");

        // fall into a loop to allow us to execute db commands...

        BufferedReader br = new BufferedReader(new InputStreamReader(System.in));
        System.out.print("> ");
        String input = br.readLine();
        while (input != null && !input.trim().equalsIgnoreCase("quit")) {
            String command = input.trim();

            try {
                if (command.equalsIgnoreCase("help")) {
                    System.out.println("commands: ");
                    System.out.println("    help\tdisplay help");
                    System.out.println("    quit\tto exit");
                    System.out.println("    sp_help\tto display all table names");
                    System.out.println(" NOTE: Everything else is interpreted as SQL");
                } else if (command.equalsIgnoreCase("sp_help")) {
                    // get all tables
                    ResultSet rs = databaseMetaData.getTables(null,null,null,new String[]{"TABLE"});
                    System.out.println("TABLE_NAME\n----------");
                    while (rs.next())
                        System.out.println(rs.getString("TABLE_NAME"));
                } else {
                    // execute sql
                    Statement statement = connection.createStatement();
                    if(statement.execute(command)){
                        ResultSet rs = statement.getResultSet();
                        displayResultSet(rs);
                    }
                }
            } catch (SQLException e) {
                // we may get some db messages. like attemping to insert
                // duplicate primary keys, droping non-existing tables,
                // creating existing tables, and all sorts of stuff that
                // can go wrong with the database.
                System.out.println(e.toString());
            }
            System.out.print("> ");
            input = br.readLine();
        }
        // before we exit, close the db connection.
        connection.close();
    }

    /**
     * displayResultSet - displays Any result set.
     */
    public static void displayResultSet(ResultSet rs) throws SQLException {
        // get meta data for this result
        ResultSetMetaData meta = rs.getMetaData();

        // get column number
        int cols = meta.getColumnCount();

        // display header information (ie: column names)
        for (int i=1;i<=cols;i++)
            System.out.print(meta.getColumnName(i)+"|");
        System.out.println("");

        // display actual data
        while (rs.next()) {
            for (int i=1;i<=cols;i++)
                System.out.print(rs.getString(i)+"|");
            System.out.println("");
        }
    }

}

/*
        // this is a sample db session using this program...

E:\projects\pages\cis270pd>javac dbconnect.java

E:\projects\pages\cis270pd>java dbconnect
Driver: sun.jdbc.odbc.JdbcOdbcDriver
Major Version: 2
Minor Version: 1

Connecting to jdbc:odbc:Test ...

Database: ACCESS
Version: 04.00.0000
User: admin
type 'help' for help. type 'quit' to exit.
> drop table Company
java.sql.SQLException: [Microsoft][ODBC Microsoft Access Driver] Cannot find table or constraint.
> create table Company (companyId INT NOT NULL)
> drop table Company
> create table Company (companyId INT NOT NULL,companyName CHAR(30),numEmployees INT,primary key(companyId))
> select * from company
companyid|companyname|numemployees|
> insert into Company (companyid,companyname,numemployees) values (1,'Particle Corp.', 1)
> select * from company
companyid|companyname|numemployees|
1|particle corp.                |1|
> insert into Company values (2,'Microsoft Corp.',12345)
> insert into company values (3,'Netscape Corp.',5432)
> select * from Company
companyid|companyname|numemployees|
1|particle corp.                |1|
2|microsoft corp.               |12345|
3|netscape corp.                |5432|
> select * from company where numemployees > 100
companyid|companyname|numemployees|
2|microsoft corp.               |12345|
3|netscape corp.                |5432|
> select * from company where companyname like '%pa%'
companyid|companyname|numemployees|
1|particle corp.                |1|
> quit

E:\projects\pages\cis270pd>java dbconnect
Driver: sun.jdbc.odbc.JdbcOdbcDriver
Major Version: 2
Minor Version: 1

Connecting to jdbc:odbc:Test ...

Database: ACCESS
Version: 04.00.0000
User: admin
type 'help' for help. type 'quit' to exit.
> sp_help
TABLE_NAME
----------
company
> select companyName from company
companyname|
particle corp.                |
microsoft corp.               |
netscape corp.                |
> quit

E:\projects\pages\cis270pd>

*/

